@@ -8,10 +8,10 @@ from .arg_parser.arg_parser import parse_cli_args
 from .arg_parser.process_args import process_args
 
 # Parse command line interface arguments to determine what this script does.
-args = parse_cli_args()
-verify_args(
-    args,
-)
-process_args(
-    args,
-)
+# args = parse_cli_args()
+# verify_args(
+    # args,
+# )
+# process_args(
+    # args,
+# )
